@@ -47,7 +47,7 @@ class View : public QWidget
 public:
     explicit View(QWidget *parent);
 
-    virtual ~View();
+    ~View() override;
 
     LogViewWidget *logViewWidget() const;
 
@@ -55,9 +55,9 @@ public:
 
     LogViewSearchWidget *logViewSearch() const;
 
-    QSize sizeHint() const;
+    QSize sizeHint() const override;
 
-public slots:
+public Q_SLOTS:
     void displayLoadingBar(bool display);
 
     void toggleLogViewFilter(bool display);
@@ -67,17 +67,17 @@ protected:
     /**
      * Method which contains the action to do when receiving a drag and drop event
      */
-    void dragEnterEvent(QDragEnterEvent *event);
+    void dragEnterEvent(QDragEnterEvent *event) override;
 
     /**
      * Method which accepts
      */
-    void dropEvent(QDropEvent *event);
+    void dropEvent(QDropEvent *event) override;
 
-private slots:
+private Q_SLOTS:
     void unselectHiddenItems();
 
-signals:
+Q_SIGNALS:
     void searchFilterChanged();
 
     void droppedUrls(const QList<QUrl> &urls);
